summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile4
-rw-r--r--src/Makefile4
-rw-r--r--src/jsapi-libdom-operator.c4
-rw-r--r--src/jsapi-libdom.c6
-rw-r--r--src/jsapi-libdom.h6
-rw-r--r--src/nsgenbind-ast.c (renamed from src/genjsbind-ast.c)24
-rw-r--r--src/nsgenbind-ast.h (renamed from src/genjsbind-ast.h)6
-rw-r--r--src/nsgenbind-lexer.l (renamed from src/genjsbind-lexer.l)8
-rw-r--r--src/nsgenbind-parser.y (renamed from src/genjsbind-parser.y)10
-rw-r--r--src/nsgenbind.c (renamed from src/genjsbind.c)4
-rw-r--r--src/options.h6
-rw-r--r--src/webidl-ast.c8
-rw-r--r--src/webidl-ast.h6
-rw-r--r--src/webidl-lexer.l2
-rw-r--r--src/webidl-parser.y2
15 files changed, 50 insertions, 50 deletions
diff --git a/Makefile b/Makefile
index ecb22d2..f149ad0 100644
--- a/Makefile
+++ b/Makefile
@@ -1,5 +1,5 @@
# Define the component name
-COMPONENT := genjsbind
+COMPONENT := nsgenbind
# And the component type
COMPONENT_TYPE := binary
# Component version
@@ -34,5 +34,5 @@ endif
# Grab the core makefile
include $(NSBUILD)/Makefile.top
-# Add extra install rules for our pkg-config control file and the library itself
+# Add extra install rules for binary
INSTALL_ITEMS := $(INSTALL_ITEMS) /bin:$(BUILDDIR)/$(COMPONENT)$(EXEEXT)
diff --git a/src/Makefile b/src/Makefile
index c4821bf..2716fa8 100644
--- a/src/Makefile
+++ b/src/Makefile
@@ -1,9 +1,9 @@
CFLAGS := $(CFLAGS) -I$(BUILDDIR) -Isrc/ -g
# Sources in this directory
-DIR_SOURCES := genjsbind.c webidl-ast.c genjsbind-ast.c jsapi-libdom.c jsapi-libdom-operator.c
+DIR_SOURCES := nsgenbind.c webidl-ast.c nsgenbind-ast.c jsapi-libdom.c jsapi-libdom-operator.c
-SOURCES := $(SOURCES) $(BUILDDIR)/genjsbind-parser.c $(BUILDDIR)/genjsbind-lexer.c $(BUILDDIR)/webidl-parser.c $(BUILDDIR)/webidl-lexer.c
+SOURCES := $(SOURCES) $(BUILDDIR)/nsgenbind-parser.c $(BUILDDIR)/nsgenbind-lexer.c $(BUILDDIR)/webidl-parser.c $(BUILDDIR)/webidl-lexer.c
$(BUILDDIR)/%-lexer.c $(BUILDDIR)/%-lexer.h: src/%-lexer.l
$(VQ)$(ECHO) " FLEX: $<"
diff --git a/src/jsapi-libdom-operator.c b/src/jsapi-libdom-operator.c
index 97369a3..0ff79c0 100644
--- a/src/jsapi-libdom-operator.c
+++ b/src/jsapi-libdom-operator.c
@@ -1,6 +1,6 @@
/* operator body generation
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -13,7 +13,7 @@
#include <stdlib.h>
#include "options.h"
-#include "genjsbind-ast.h"
+#include "nsgenbind-ast.h"
#include "webidl-ast.h"
#include "jsapi-libdom.h"
diff --git a/src/jsapi-libdom.c b/src/jsapi-libdom.c
index fdcebe7..1dad62a 100644
--- a/src/jsapi-libdom.c
+++ b/src/jsapi-libdom.c
@@ -1,6 +1,6 @@
/* binding output generator for jsapi(spidermonkey) to libdom
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -13,12 +13,12 @@
#include <stdlib.h>
#include "options.h"
-#include "genjsbind-ast.h"
+#include "nsgenbind-ast.h"
#include "webidl-ast.h"
#include "jsapi-libdom.h"
#define HDR_COMMENT_SEP "\n * "
-#define HDR_COMMENT_PREABLE "Generated by nsgenjsapi"
+#define HDR_COMMENT_PREABLE "Generated by nsgenbind "
static int webidl_file_cb(struct genbind_node *node, void *ctx)
diff --git a/src/jsapi-libdom.h b/src/jsapi-libdom.h
index e199ec7..67d4238 100644
--- a/src/jsapi-libdom.h
+++ b/src/jsapi-libdom.h
@@ -1,13 +1,13 @@
/* binding generator output
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
*/
-#ifndef genjsbind_jsapi_libdom_h
-#define genjsbind_jsapi_libdom_h
+#ifndef nsgenbind_jsapi_libdom_h
+#define nsgenbind_jsapi_libdom_h
struct binding {
struct genbind_node *gb_ast;
diff --git a/src/genjsbind-ast.h b/src/nsgenbind-ast.h
index 416fa7b..b51e6b8 100644
--- a/src/genjsbind-ast.h
+++ b/src/nsgenbind-ast.h
@@ -1,13 +1,13 @@
/* binding file AST interface
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsnsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
*/
-#ifndef genjsbind_genjsbind_ast_h
-#define genjsbind_genjsbind_ast_h
+#ifndef nsgenbind_nsgenbind_ast_h
+#define nsgenbind_nsgenbind_ast_h
enum genbind_node_type {
GENBIND_NODE_TYPE_ROOT = 0,
diff --git a/src/genjsbind-lexer.l b/src/nsgenbind-lexer.l
index 3701252..4bdc803 100644
--- a/src/genjsbind-lexer.l
+++ b/src/nsgenbind-lexer.l
@@ -2,7 +2,7 @@
/* lexer for the binding generation config file
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -12,8 +12,8 @@
#include <stdio.h>
#include <string.h>
-#include "genjsbind-parser.h"
-#include "genjsbind-ast.h"
+#include "nsgenbind-parser.h"
+#include "nsgenbind-ast.h"
#define YY_USER_ACTION yylloc->first_line = yylloc->last_line; \
yylloc->first_column = yylloc->last_column + 1; \
@@ -28,7 +28,7 @@
%option bison-locations
%option nodefault
%option warn
-%option prefix="genjsbind_"
+%option prefix="nsgenbind_"
%option nounput
%option noinput
%option noyywrap
diff --git a/src/genjsbind-parser.y b/src/nsgenbind-parser.y
index cf9ab61..500f4b8 100644
--- a/src/genjsbind-parser.y
+++ b/src/nsgenbind-parser.y
@@ -1,7 +1,7 @@
%{
/* parser for the binding generation config file
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -10,14 +10,14 @@
#include <stdio.h>
#include <string.h>
-#include "genjsbind-parser.h"
-#include "genjsbind-lexer.h"
+#include "nsgenbind-parser.h"
+#include "nsgenbind-lexer.h"
#include "webidl-ast.h"
-#include "genjsbind-ast.h"
+#include "nsgenbind-ast.h"
char *errtxt;
- static void genjsbind_error(YYLTYPE *locp, struct genbind_node **genbind_ast, const char *str)
+ static void nsgenbind_error(YYLTYPE *locp, struct genbind_node **genbind_ast, const char *str)
{
locp = locp;
genbind_ast = genbind_ast;
diff --git a/src/genjsbind.c b/src/nsgenbind.c
index bcaf62f..14854ad 100644
--- a/src/genjsbind.c
+++ b/src/nsgenbind.c
@@ -1,6 +1,6 @@
/* binding generator main and command line parsing
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -14,7 +14,7 @@
#include <getopt.h>
#include <errno.h>
-#include "genjsbind-ast.h"
+#include "nsgenbind-ast.h"
#include "jsapi-libdom.h"
#include "options.h"
diff --git a/src/options.h b/src/options.h
index 041f4cd..696a907 100644
--- a/src/options.h
+++ b/src/options.h
@@ -1,13 +1,13 @@
/* binding generator options
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
*/
-#ifndef genjsbind_options_h
-#define genjsbind_options_h
+#ifndef nsgenbind_options_h
+#define nsgenbind_options_h
struct options {
char *outfilename;
diff --git a/src/webidl-ast.c b/src/webidl-ast.c
index 7e6fc2c..fef5f35 100644
--- a/src/webidl-ast.c
+++ b/src/webidl-ast.c
@@ -1,6 +1,6 @@
/* AST generator for the WEB IDL parser
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -136,7 +136,7 @@ webidl_node_for_each_type(struct webidl_node *node,
return 0;
}
-/* exported interface defined in genjsbind-ast.h */
+/* exported interface defined in webidl-ast.h */
int webidl_cmp_node_type(struct webidl_node *node, void *ctx)
{
if (node->type == (enum webidl_node_type)ctx)
@@ -144,7 +144,7 @@ int webidl_cmp_node_type(struct webidl_node *node, void *ctx)
return 0;
}
-/* exported interface defined in genjsbind-ast.h */
+/* exported interface defined in webidl-ast.h */
struct webidl_node *
webidl_node_find(struct webidl_node *node,
struct webidl_node *prev,
@@ -172,7 +172,7 @@ webidl_node_find(struct webidl_node *node,
}
-/* exported interface defined in genjsbind-ast.h */
+/* exported interface defined in webidl-ast.h */
struct webidl_node *
webidl_node_find_type(struct webidl_node *node,
struct webidl_node *prev,
diff --git a/src/webidl-ast.h b/src/webidl-ast.h
index 8e14fa4..2117cfa 100644
--- a/src/webidl-ast.h
+++ b/src/webidl-ast.h
@@ -1,13 +1,13 @@
/* Web IDL AST interface
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
*/
-#ifndef genjsbind_webidl_ast_h
-#define genjsbind_webidl_ast_h
+#ifndef nsgenbind_webidl_ast_h
+#define nsgenbind_webidl_ast_h
enum webidl_node_type {
/* generic node types which define structure or attributes */
diff --git a/src/webidl-lexer.l b/src/webidl-lexer.l
index bfa4fb5..5369d99 100644
--- a/src/webidl-lexer.l
+++ b/src/webidl-lexer.l
@@ -2,7 +2,7 @@
/* This is a unicode tolerant lexer for web IDL
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
diff --git a/src/webidl-parser.y b/src/webidl-parser.y
index 74af1c1..2fe549b 100644
--- a/src/webidl-parser.y
+++ b/src/webidl-parser.y
@@ -2,7 +2,7 @@
/* This is a bison parser for Web IDL
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
diff --git a/src/genjsbind-ast.c b/src/nsgenbind-ast.c
index c3329cf..646548b 100644
--- a/src/genjsbind-ast.c
+++ b/src/nsgenbind-ast.c
@@ -1,6 +1,6 @@
/* binding generator AST implementation for parser
*
* This file is part of nsgenjsbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
* Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
@@ -15,14 +15,14 @@
#include <errno.h>
#include <string.h>
-#include "genjsbind-ast.h"
+#include "nsgenbind-ast.h"
#include "options.h"
/* parser and lexer interface */
-extern int genjsbind_debug;
-extern int genjsbind__flex_debug;
-extern void genjsbind_restart(FILE*);
-extern int genjsbind_parse(struct genbind_node **genbind_ast);
+extern int nsgenbind_debug;
+extern int nsgenbind__flex_debug;
+extern void nsgenbind_restart(FILE*);
+extern int nsgenbind_parse(struct genbind_node **genbind_ast);
/* terminal nodes have a value only */
struct genbind_node {
@@ -91,7 +91,7 @@ genbind_node_for_each_type(struct genbind_node *node,
}
/* exported interface defined in genjsbind-ast.h */
struct genbind_node *
genbind_node_find(struct genbind_node *node,
struct genbind_node *prev,
@@ -118,7 +118,7 @@ genbind_node_find(struct genbind_node *node,
return NULL;
}
/* exported interface defined in genjsbind-ast.h */
struct genbind_node *
genbind_node_find_type(struct genbind_node *node,
struct genbind_node *prev,
@@ -350,14 +350,14 @@ int genbind_parsefile(char *infilename, struct genbind_node **ast)
}
if (options->debug) {
- genjsbind_debug = 1;
- genjsbind__flex_debug = 1;
+ nsgenbind_debug = 1;
+ nsgenbind__flex_debug = 1;
}
/* set flex to read from file */
- genjsbind_restart(infile);
+ nsgenbind_restart(infile);
/* process binding */
- return genjsbind_parse(ast);
+ return nsgenbind_parse(ast);
}
@@ -1,6 +1,6 @@
/* binding generator AST implementation for parser
*
- * This file is part of nsgenjsbind.
+ * This file is part of nsgenbind.
* Licensed under the MIT License,
* http://www.opensource.org/licenses/mit-license.php
@@ -91,7 +91,7 @@ genbind_node_for_each_type(struct genbind_node *node,
}
-/* exported interface defined in genjsbind-ast.h */
+/* exported interface defined in nsgenbind-ast.h */
struct genbind_node *
genbind_node_find(struct genbind_node *node,
@@ -118,7 +118,7 @@ genbind_node_find(struct genbind_node *node,
return NULL;
}
-/* exported interface defined in genjsbind-ast.h */
+/* exported interface defined in nsgenbind-ast.h */
struct genbind_node *
genbind_node_find_type(struct genbind_node *node,